==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Polyhedron/classCGAL_1_1Polyhedron__3.js <==
var classCGAL_1_1Polyhedron__3 =
[
    [ "allocator_type", "classCGAL_1_1Polyhedron__3.html#add0588183a0e107bd7e2dc78909ca127", null ],
    [ "circulator_category", "classCGAL_1_1Polyhedron__3.html#a72c27f9439dcb1889505ecece9b4e206", null ],
    [ "difference_type", "classCGAL_1_1Polyhedron__3.html#abac442c83261a025d773fcf2a64cd953", null ],
    [ "Edge_iterator", "classCGAL_1_1Polyhedron__3.html#a260c899118aefbf92f85dcd72ce43851", null ],
    [ "Edges", "classCGAL_1_1Polyhedron__3.html#a1dfc0b86a7634374c1ec25f3bf6fbb2d", null ],
    [ "Facet_handle", "classCGAL_1_1Polyhedron__3.html#ad44731fbb60766ae1ea8e46b69d3cbbf", null ],
    [ "Facet_handles", "classCGAL_1_1Polyhedron__3.html#a53b1123a65846e5e61a6bb0fd29bf847", null ],
    [ "Facet_iterator", "classCGAL_1_1Polyhedron__3.html#a11883e7be5e610e823ebb46605e8772f", null ],
    [ "Halfedge_around_facet_circulator", "classCGAL_1_1Polyhedron__3.html#aaa493b9f4e392204345ecf79ebbd37e8", null ],
    [ "Halfedge_around_vertex_circulator", "classCGAL_1_1Polyhedron__3.html#a0bed29e3f406b13c8605f3f3e98d7175", null ],
    [ "Halfedge_handle", "classCGAL_1_1Polyhedron__3.html#a5ea0a8e088c2e98a6f1312d32f0a4967", null ],
    [ "Halfedge_handles", "classCGAL_1_1Polyhedron__3.html#a6659085c476499a617c39ef16f54e84e", null ],
    [ "Halfedge_iterator", "classCGAL_1_1Polyhedron__3.html#a6c11afde7bae6be0cc0006d0b2512a19", null ],
    [ "HalfedgeDS", "classCGAL_1_1Polyhedron__3.html#ab17a61da2a32f50b861cc261cd32c0bd", null ],
    [ "Items", "classCGAL_1_1Polyhedron__3.html#a82fc1b399742114ebc63c98405885e7b", null ],
    [ "iterator_category", "classCGAL_1_1Polyhedron__3.html#a7d6cdf0e8d7b13cb6d301987c1612b3c", null ],
    [ "Plane_3", "classCGAL_1_1Polyhedron__3.html#aa6d5d215f46423546681237d07a1e584", null ],
    [ "Plane_iterator", "classCGAL_1_1Polyhedron__3.html#af268be0ffff77469b60afbc4b4893ed5", null ],
    [ "Planes", "classCGAL_1_1Polyhedron__3.html#a746e4a0e5d32824f9bb001bdf254da13", null ],
    [ "Point_3", "classCGAL_1_1Polyhedron__3.html#a59bebced7ecd7660dd3ab1d33d22566f", null ],
    [ "Point_iterator", "classCGAL_1_1Polyhedron__3.html#a6aff2b5a8cb76cede147e32f500ad311", null ],
    [ "Points", "classCGAL_1_1Polyhedron__3.html#a11f504c4c3c7759eb0a5becb22c40ac1", null ],
    [ "size_type", "classCGAL_1_1Polyhedron__3.html#a859fcfdd3fa1df1ec6c2c98d10b85edb", null ],
    [ "Supports_facet_halfedge", "classCGAL_1_1Polyhedron__3.html#adb9c5380cb7d80196eff14e36c6a4ba1", null ],
    [ "Supports_facet_plane", "classCGAL_1_1Polyhedron__3.html#a1f2c8a28ffea579d07a50fcfcbd04e1c", null ],
    [ "Supports_halfedge_facet", "classCGAL_1_1Polyhedron__3.html#a04847ba8c46f51dacc38cff5640132e9", null ],
    [ "Supports_halfedge_prev", "classCGAL_1_1Polyhedron__3.html#a30a165f364597483f4ac1334642f4c51", null ],
    [ "Supports_halfedge_vertex", "classCGAL_1_1Polyhedron__3.html#a0acbd6f11423457c8cd0a194aa17eb1f", null ],
    [ "Supports_removal", "classCGAL_1_1Polyhedron__3.html#a1ea6e410d683cb382b1af84b85df70b9", null ],
    [ "Supports_vertex_halfedge", "classCGAL_1_1Polyhedron__3.html#ad575271460a9df1492e1f0f339f5bd31", null ],
    [ "Supports_vertex_point", "classCGAL_1_1Polyhedron__3.html#a62d1d69b081470716688036d66f4be7e", null ],
    [ "Vertex_handle", "classCGAL_1_1Polyhedron__3.html#aca51106e581d51d36bd668c819c0ac4e", null ],
    [ "Vertex_handles", "classCGAL_1_1Polyhedron__3.html#a675da64ded520fe6abca063ada3a1ed8", null ],
    [ "Vertex_iterator", "classCGAL_1_1Polyhedron__3.html#aff9ec9b39223e4f1cdf69ab39838e9e3", null ],
    [ "Polyhedron_3", "classCGAL_1_1Polyhedron__3.html#a58827beef13f3dd6b67f8337709bc501", null ],
    [ "Polyhedron_3", "classCGAL_1_1Polyhedron__3.html#a8bf0e9e52526da081375a7b49ca8b195", null ],
    [ "add_facet_to_border", "classCGAL_1_1Polyhedron__3.html#a73119c0c90bf8612da003305af25a52a", null ],
    [ "add_vertex_and_facet_to_border", "classCGAL_1_1Polyhedron__3.html#a684bc8315f9e97d59e10bf896f0a166c", null ],
    [ "border_edges_begin", "classCGAL_1_1Polyhedron__3.html#a4c3aeee01fe5fab394f364d5b117a21b", null ],
    [ "border_halfedges_begin", "classCGAL_1_1Polyhedron__3.html#acf8b79d9652f049ca360d805f73ba16f", null ],
    [ "bytes", "classCGAL_1_1Polyhedron__3.html#aa889170efd14f009004ab521606dc605", null ],
    [ "bytes_reserved", "classCGAL_1_1Polyhedron__3.html#a47000d54bd804fed1e4cc45c2dea122e", null ],
    [ "capacity_of_facets", "classCGAL_1_1Polyhedron__3.html#ac70e38b205cfcdbaa0a51d047f16e01d", null ],
    [ "capacity_of_halfedges", "classCGAL_1_1Polyhedron__3.html#a56711d646b29d468566e9e7371d36f93", null ],
    [ "capacity_of_vertices", "classCGAL_1_1Polyhedron__3.html#a5d999a50161f1353143e8d64e889ebc5", null ],
    [ "clear", "classCGAL_1_1Polyhedron__3.html#a87ed6b369ce8b0c6ad22f7a20dc6dbc9", null ],
    [ "create_center_vertex", "classCGAL_1_1Polyhedron__3.html#aca3b991cd6d926fd5b51b25766d36fad", null ],
    [ "delegate", "classCGAL_1_1Polyhedron__3.html#a7d5683b471d99bff3d73a467688151c5", null ],
    [ "edges", "classCGAL_1_1Polyhedron__3.html#a3c6662c06a8bb50b271fea179dd07fa3", null ],
    [ "edges_begin", "classCGAL_1_1Polyhedron__3.html#a251ab9cb55e77ad4ad6923914d5e65ea", null ],
    [ "edges_end", "classCGAL_1_1Polyhedron__3.html#a9ea95c5501c1af4d6a17b18c929c8faf", null ],
    [ "empty", "classCGAL_1_1Polyhedron__3.html#a8ce3e77931cf80fcda9c3c89564f1443", null ],
    [ "erase_center_vertex", "classCGAL_1_1Polyhedron__3.html#a2d08e7da8a337ed90b0db2e9a37d21c6", null ],
    [ "erase_connected_component", "classCGAL_1_1Polyhedron__3.html#a8497a896e1f23905c04accf99957afa1", null ],
    [ "erase_facet", "classCGAL_1_1Polyhedron__3.html#ac67041483c1e7c67c8dfd87716feebea", null ],
    [ "facet_handles", "classCGAL_1_1Polyhedron__3.html#a77a50500124207ecc42e8da2b47e0012", null ],
    [ "facets_begin", "classCGAL_1_1Polyhedron__3.html#a7bdcf3f2936fa9a27faf91536d953cba", null ],
    [ "facets_end", "classCGAL_1_1Polyhedron__3.html#ab34dd6ee47881cc822f578a9ba534f83", null ],
    [ "fill_hole", "classCGAL_1_1Polyhedron__3.html#ae05ca3c53d3ec0ce9e84c4b173b48e3e", null ],
    [ "flip_edge", "classCGAL_1_1Polyhedron__3.html#a633723d9b2f8a5972b8bfb4a4ea601ee", null ],
    [ "get_allocator", "classCGAL_1_1Polyhedron__3.html#ab741e3641ed4363ab156022525f82171", null ],
    [ "halfedge_handles", "classCGAL_1_1Polyhedron__3.html#aa5b19c47be114464b47a91bc60372c7c", null ],
    [ "halfedges_begin", "classCGAL_1_1Polyhedron__3.html#a8d38f95397f743187bdd389b2f83a3c4", null ],
    [ "halfedges_end", "classCGAL_1_1Polyhedron__3.html#abe1c7ae1fab1b3c7315b32d5d34ff2de", null ],
    [ "inside_out", "classCGAL_1_1Polyhedron__3.html#ac12b817b3d651cce74fbdaa711bacf33", null ],
    [ "is_closed", "classCGAL_1_1Polyhedron__3.html#a4afb025815064d4f125b8d3b0ba2b6f7", null ],
    [ "is_pure_bivalent", "classCGAL_1_1Polyhedron__3.html#a2415e1795ff4257b2080e60490124d3d", null ],
    [ "is_pure_quad", "classCGAL_1_1Polyhedron__3.html#affb9ffd609b66df43da8b3a7c352ccdc", null ],
    [ "is_pure_triangle", "classCGAL_1_1Polyhedron__3.html#a13ab704a6d26eb91c55cdb6828442ab1", null ],
    [ "is_pure_trivalent", "classCGAL_1_1Polyhedron__3.html#abb5fbc55c8a0e94ec9720fc951632ab0", null ],
    [ "is_tetrahedron", "classCGAL_1_1Polyhedron__3.html#af8993fad62cbddf613a26285bdb9fee8", null ],
    [ "is_triangle", "classCGAL_1_1Polyhedron__3.html#a0ff0a8c56eb8020fa517fca70b9b08d1", null ],
    [ "is_valid", "classCGAL_1_1Polyhedron__3.html#a3d67f3adbc2965b2ea54607d4f85ae89", null ],
    [ "join_facet", "classCGAL_1_1Polyhedron__3.html#a4f3e7c4e0800462026443a7ad0ca6db8", null ],
    [ "join_loop", "classCGAL_1_1Polyhedron__3.html#ad5a29fe94196629193da3c95e5eba5e9", null ],
    [ "join_vertex", "classCGAL_1_1Polyhedron__3.html#a8edb13d0fb5748b20a8173bec85e7243", null ],
    [ "keep_largest_connected_components", "classCGAL_1_1Polyhedron__3.html#a55f13c9c3dd5ab611d08dcd346d9190e", null ],
    [ "make_hole", "classCGAL_1_1Polyhedron__3.html#a228add3cae2d328bcdd67192a98fb636", null ],
    [ "make_tetrahedron", "classCGAL_1_1Polyhedron__3.html#a1ebc714bb6fc75a8aa105ffb241fe087", null ],
    [ "make_tetrahedron", "classCGAL_1_1Polyhedron__3.html#a19d554cc3a0e2db78b88d4e074c9fa19", null ],
    [ "make_triangle", "classCGAL_1_1Polyhedron__3.html#a06735e9d5caa84f0afb5ddab37a9dedf", null ],
    [ "make_triangle", "classCGAL_1_1Polyhedron__3.html#a62241505a5199ec963acd2a6fda4239f", null ],
    [ "normalize_border", "classCGAL_1_1Polyhedron__3.html#a6ca5eddcfe19c5b69a500f39a0bfdbe5", null ],
    [ "normalized_border_is_valid", "classCGAL_1_1Polyhedron__3.html#adb2db37bc2fcdd3e051260af9259f34e", null ],
    [ "planes", "classCGAL_1_1Polyhedron__3.html#aaf451356d666be3060567dd904bfb38f", null ],
    [ "planes_begin", "classCGAL_1_1Polyhedron__3.html#a409be107a687d3813b91f84a6e4459c9", null ],
    [ "planes_end", "classCGAL_1_1Polyhedron__3.html#abb6712371c2355442e42b6846bbc0375", null ],
    [ "points", "classCGAL_1_1Polyhedron__3.html#af6abde1634fdd64d79e78f07145186f2", null ],
    [ "points_begin", "classCGAL_1_1Polyhedron__3.html#a25d5ad0a16bbcf71ca1f48225b43bc95", null ],
    [ "points_end", "classCGAL_1_1Polyhedron__3.html#a45bf32fbaf7f185558e18194e4ab3830", null ],
    [ "reserve", "classCGAL_1_1Polyhedron__3.html#a545fadc0f4af7a1e4a1a0d1e26711f17", null ],
    [ "size_of_border_edges", "classCGAL_1_1Polyhedron__3.html#a1a1dbed72ce1b001446dd3ce25155d30", null ],
    [ "size_of_border_halfedges", "classCGAL_1_1Polyhedron__3.html#af156bdee96bbf065953569fe026795d9", null ],
    [ "size_of_facets", "classCGAL_1_1Polyhedron__3.html#a07c305cf6da9eeecc89fea2fc4f24f67", null ],
    [ "size_of_halfedges", "classCGAL_1_1Polyhedron__3.html#a022b5c320996fabb49673d8921437fcb", null ],
    [ "size_of_vertices", "classCGAL_1_1Polyhedron__3.html#ad661d362a8e515d67108803796eabac8", null ],
    [ "split_edge", "classCGAL_1_1Polyhedron__3.html#ab3269baf4b4c6ce61b86545b8fa360d2", null ],
    [ "split_facet", "classCGAL_1_1Polyhedron__3.html#a3ef41ae6c3be7f0894479f3dd4fe34d5", null ],
    [ "split_loop", "classCGAL_1_1Polyhedron__3.html#a375a1b49bc6ad2ad5c578d7a7c45e4f5", null ],
    [ "split_vertex", "classCGAL_1_1Polyhedron__3.html#a2b17d7bd2045397167b00616f3b4d622", null ],
    [ "traits", "classCGAL_1_1Polyhedron__3.html#a2eff5c59b448f9be755cb76cdf06d966", null ],
    [ "vertex_handles", "classCGAL_1_1Polyhedron__3.html#a2e0843aaeeadc428e8cd25802109bdf5", null ],
    [ "vertices_begin", "classCGAL_1_1Polyhedron__3.html#a94eec0aaf19925a005e5296d6c965c55", null ],
    [ "vertices_end", "classCGAL_1_1Polyhedron__3.html#aa402ee6ce24e0259a45c8579784a0f9a", null ],
    [ "operator<<", "group__PkgPolyhedronIOFunc.html#ga0672e8be92f0b71fe624525f80f850d0", null ],
    [ "operator>>", "group__PkgPolyhedronIOFunc.html#ga9842e8b5cda1e38ad04aa7f80622bce3", null ],
    [ "read_OFF", "group__PkgPolyhedronIOFunc.html#gaccd9d4d15af1376dbc166eb501f28980", null ],
    [ "read_off", "classCGAL_1_1Polyhedron__3.html#aeb28b4c481248fce96a79bf513f0d715", null ],
    [ "write_OFF", "group__PkgPolyhedronIOFunc.html#ga408af896e2203af605059494e620cb64", null ],
    [ "write_off", "classCGAL_1_1Polyhedron__3.html#ab9cb7a5361ace492fe0a7fbf758a5711", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Polyhedron/classCGAL_1_1Polyhedron__3.js <==
var classCGAL_1_1Polyhedron__3 =
[
    [ "allocator_type", "classCGAL_1_1Polyhedron__3.html#add0588183a0e107bd7e2dc78909ca127", null ],
    [ "circulator_category", "classCGAL_1_1Polyhedron__3.html#a72c27f9439dcb1889505ecece9b4e206", null ],
    [ "difference_type", "classCGAL_1_1Polyhedron__3.html#abac442c83261a025d773fcf2a64cd953", null ],
    [ "Edge_iterator", "classCGAL_1_1Polyhedron__3.html#a260c899118aefbf92f85dcd72ce43851", null ],
    [ "Edges", "classCGAL_1_1Polyhedron__3.html#a1dfc0b86a7634374c1ec25f3bf6fbb2d", null ],
    [ "Facet_handle", "classCGAL_1_1Polyhedron__3.html#ad44731fbb60766ae1ea8e46b69d3cbbf", null ],
    [ "Facet_handles", "classCGAL_1_1Polyhedron__3.html#a53b1123a65846e5e61a6bb0fd29bf847", null ],
    [ "Facet_iterator", "classCGAL_1_1Polyhedron__3.html#a11883e7be5e610e823ebb46605e8772f", null ],
    [ "Halfedge_around_facet_circulator", "classCGAL_1_1Polyhedron__3.html#aaa493b9f4e392204345ecf79ebbd37e8", null ],
    [ "Halfedge_around_vertex_circulator", "classCGAL_1_1Polyhedron__3.html#a0bed29e3f406b13c8605f3f3e98d7175", null ],
    [ "Halfedge_handle", "classCGAL_1_1Polyhedron__3.html#a5ea0a8e088c2e98a6f1312d32f0a4967", null ],
    [ "Halfedge_handles", "classCGAL_1_1Polyhedron__3.html#a6659085c476499a617c39ef16f54e84e", null ],
    [ "Halfedge_iterator", "classCGAL_1_1Polyhedron__3.html#a6c11afde7bae6be0cc0006d0b2512a19", null ],
    [ "HalfedgeDS", "classCGAL_1_1Polyhedron__3.html#ab17a61da2a32f50b861cc261cd32c0bd", null ],
    [ "Items", "classCGAL_1_1Polyhedron__3.html#a82fc1b399742114ebc63c98405885e7b", null ],
    [ "iterator_category", "classCGAL_1_1Polyhedron__3.html#a7d6cdf0e8d7b13cb6d301987c1612b3c", null ],
    [ "Plane_3", "classCGAL_1_1Polyhedron__3.html#aa6d5d215f46423546681237d07a1e584", null ],
    [ "Plane_iterator", "classCGAL_1_1Polyhedron__3.html#af268be0ffff77469b60afbc4b4893ed5", null ],
    [ "Planes", "classCGAL_1_1Polyhedron__3.html#a746e4a0e5d32824f9bb001bdf254da13", null ],
    [ "Point_3", "classCGAL_1_1Polyhedron__3.html#a59bebced7ecd7660dd3ab1d33d22566f", null ],
    [ "Point_iterator", "classCGAL_1_1Polyhedron__3.html#a6aff2b5a8cb76cede147e32f500ad311", null ],
    [ "Points", "classCGAL_1_1Polyhedron__3.html#a11f504c4c3c7759eb0a5becb22c40ac1", null ],
    [ "size_type", "classCGAL_1_1Polyhedron__3.html#a859fcfdd3fa1df1ec6c2c98d10b85edb", null ],
    [ "Supports_facet_halfedge", "classCGAL_1_1Polyhedron__3.html#adb9c5380cb7d80196eff14e36c6a4ba1", null ],
    [ "Supports_facet_plane", "classCGAL_1_1Polyhedron__3.html#a1f2c8a28ffea579d07a50fcfcbd04e1c", null ],
    [ "Supports_halfedge_facet", "classCGAL_1_1Polyhedron__3.html#a04847ba8c46f51dacc38cff5640132e9", null ],
    [ "Supports_halfedge_prev", "classCGAL_1_1Polyhedron__3.html#a30a165f364597483f4ac1334642f4c51", null ],
    [ "Supports_halfedge_vertex", "classCGAL_1_1Polyhedron__3.html#a0acbd6f11423457c8cd0a194aa17eb1f", null ],
    [ "Supports_removal", "classCGAL_1_1Polyhedron__3.html#a1ea6e410d683cb382b1af84b85df70b9", null ],
    [ "Supports_vertex_halfedge", "classCGAL_1_1Polyhedron__3.html#ad575271460a9df1492e1f0f339f5bd31", null ],
    [ "Supports_vertex_point", "classCGAL_1_1Polyhedron__3.html#a62d1d69b081470716688036d66f4be7e", null ],
    [ "Vertex_handle", "classCGAL_1_1Polyhedron__3.html#aca51106e581d51d36bd668c819c0ac4e", null ],
    [ "Vertex_handles", "classCGAL_1_1Polyhedron__3.html#a675da64ded520fe6abca063ada3a1ed8", null ],
    [ "Vertex_iterator", "classCGAL_1_1Polyhedron__3.html#aff9ec9b39223e4f1cdf69ab39838e9e3", null ],
    [ "Polyhedron_3", "classCGAL_1_1Polyhedron__3.html#a58827beef13f3dd6b67f8337709bc501", null ],
    [ "Polyhedron_3", "classCGAL_1_1Polyhedron__3.html#a8bf0e9e52526da081375a7b49ca8b195", null ],
    [ "add_facet_to_border", "classCGAL_1_1Polyhedron__3.html#a73119c0c90bf8612da003305af25a52a", null ],
    [ "add_vertex_and_facet_to_border", "classCGAL_1_1Polyhedron__3.html#a684bc8315f9e97d59e10bf896f0a166c", null ],
    [ "border_edges_begin", "classCGAL_1_1Polyhedron__3.html#a4c3aeee01fe5fab394f364d5b117a21b", null ],
    [ "border_halfedges_begin", "classCGAL_1_1Polyhedron__3.html#acf8b79d9652f049ca360d805f73ba16f", null ],
    [ "bytes", "classCGAL_1_1Polyhedron__3.html#aa889170efd14f009004ab521606dc605", null ],
    [ "bytes_reserved", "classCGAL_1_1Polyhedron__3.html#a47000d54bd804fed1e4cc45c2dea122e", null ],
    [ "capacity_of_facets", "classCGAL_1_1Polyhedron__3.html#ac70e38b205cfcdbaa0a51d047f16e01d", null ],
    [ "capacity_of_halfedges", "classCGAL_1_1Polyhedron__3.html#a56711d646b29d468566e9e7371d36f93", null ],
    [ "capacity_of_vertices", "classCGAL_1_1Polyhedron__3.html#a5d999a50161f1353143e8d64e889ebc5", null ],
    [ "clear", "classCGAL_1_1Polyhedron__3.html#a87ed6b369ce8b0c6ad22f7a20dc6dbc9", null ],
    [ "create_center_vertex", "classCGAL_1_1Polyhedron__3.html#aca3b991cd6d926fd5b51b25766d36fad", null ],
    [ "delegate", "classCGAL_1_1Polyhedron__3.html#a7d5683b471d99bff3d73a467688151c5", null ],
    [ "edges", "classCGAL_1_1Polyhedron__3.html#a3c6662c06a8bb50b271fea179dd07fa3", null ],
    [ "edges_begin", "classCGAL_1_1Polyhedron__3.html#a251ab9cb55e77ad4ad6923914d5e65ea", null ],
    [ "edges_end", "classCGAL_1_1Polyhedron__3.html#a9ea95c5501c1af4d6a17b18c929c8faf", null ],
    [ "empty", "classCGAL_1_1Polyhedron__3.html#a8ce3e77931cf80fcda9c3c89564f1443", null ],
    [ "erase_center_vertex", "classCGAL_1_1Polyhedron__3.html#a2d08e7da8a337ed90b0db2e9a37d21c6", null ],
    [ "erase_connected_component", "classCGAL_1_1Polyhedron__3.html#a8497a896e1f23905c04accf99957afa1", null ],
    [ "erase_facet", "classCGAL_1_1Polyhedron__3.html#ac67041483c1e7c67c8dfd87716feebea", null ],
    [ "facet_handles", "classCGAL_1_1Polyhedron__3.html#a77a50500124207ecc42e8da2b47e0012", null ],
    [ "facets_begin", "classCGAL_1_1Polyhedron__3.html#a7bdcf3f2936fa9a27faf91536d953cba", null ],
    [ "facets_end", "classCGAL_1_1Polyhedron__3.html#ab34dd6ee47881cc822f578a9ba534f83", null ],
    [ "fill_hole", "classCGAL_1_1Polyhedron__3.html#ae05ca3c53d3ec0ce9e84c4b173b48e3e", null ],
    [ "flip_edge", "classCGAL_1_1Polyhedron__3.html#a633723d9b2f8a5972b8bfb4a4ea601ee", null ],
    [ "get_allocator", "classCGAL_1_1Polyhedron__3.html#ab741e3641ed4363ab156022525f82171", null ],
    [ "halfedge_handles", "classCGAL_1_1Polyhedron__3.html#aa5b19c47be114464b47a91bc60372c7c", null ],
    [ "halfedges_begin", "classCGAL_1_1Polyhedron__3.html#a8d38f95397f743187bdd389b2f83a3c4", null ],
    [ "halfedges_end", "classCGAL_1_1Polyhedron__3.html#abe1c7ae1fab1b3c7315b32d5d34ff2de", null ],
    [ "inside_out", "classCGAL_1_1Polyhedron__3.html#ac12b817b3d651cce74fbdaa711bacf33", null ],
    [ "is_closed", "classCGAL_1_1Polyhedron__3.html#a4afb025815064d4f125b8d3b0ba2b6f7", null ],
    [ "is_pure_bivalent", "classCGAL_1_1Polyhedron__3.html#a2415e1795ff4257b2080e60490124d3d", null ],
    [ "is_pure_quad", "classCGAL_1_1Polyhedron__3.html#affb9ffd609b66df43da8b3a7c352ccdc", null ],
    [ "is_pure_triangle", "classCGAL_1_1Polyhedron__3.html#a13ab704a6d26eb91c55cdb6828442ab1", null ],
    [ "is_pure_trivalent", "classCGAL_1_1Polyhedron__3.html#abb5fbc55c8a0e94ec9720fc951632ab0", null ],
    [ "is_tetrahedron", "classCGAL_1_1Polyhedron__3.html#af8993fad62cbddf613a26285bdb9fee8", null ],
    [ "is_triangle", "classCGAL_1_1Polyhedron__3.html#a0ff0a8c56eb8020fa517fca70b9b08d1", null ],
    [ "is_valid", "classCGAL_1_1Polyhedron__3.html#a3d67f3adbc2965b2ea54607d4f85ae89", null ],
    [ "join_facet", "classCGAL_1_1Polyhedron__3.html#a4f3e7c4e0800462026443a7ad0ca6db8", null ],
    [ "join_loop", "classCGAL_1_1Polyhedron__3.html#ad5a29fe94196629193da3c95e5eba5e9", null ],
    [ "join_vertex", "classCGAL_1_1Polyhedron__3.html#a8edb13d0fb5748b20a8173bec85e7243", null ],
    [ "keep_largest_connected_components", "classCGAL_1_1Polyhedron__3.html#a55f13c9c3dd5ab611d08dcd346d9190e", null ],
    [ "make_hole", "classCGAL_1_1Polyhedron__3.html#a228add3cae2d328bcdd67192a98fb636", null ],
    [ "make_tetrahedron", "classCGAL_1_1Polyhedron__3.html#a1ebc714bb6fc75a8aa105ffb241fe087", null ],
    [ "make_tetrahedron", "classCGAL_1_1Polyhedron__3.html#a19d554cc3a0e2db78b88d4e074c9fa19", null ],
    [ "make_triangle", "classCGAL_1_1Polyhedron__3.html#a06735e9d5caa84f0afb5ddab37a9dedf", null ],
    [ "make_triangle", "classCGAL_1_1Polyhedron__3.html#a62241505a5199ec963acd2a6fda4239f", null ],
    [ "normalize_border", "classCGAL_1_1Polyhedron__3.html#a6ca5eddcfe19c5b69a500f39a0bfdbe5", null ],
    [ "normalized_border_is_valid", "classCGAL_1_1Polyhedron__3.html#adb2db37bc2fcdd3e051260af9259f34e", null ],
    [ "planes", "classCGAL_1_1Polyhedron__3.html#aaf451356d666be3060567dd904bfb38f", null ],
    [ "planes_begin", "classCGAL_1_1Polyhedron__3.html#a409be107a687d3813b91f84a6e4459c9", null ],
    [ "planes_end", "classCGAL_1_1Polyhedron__3.html#abb6712371c2355442e42b6846bbc0375", null ],
    [ "points", "classCGAL_1_1Polyhedron__3.html#af6abde1634fdd64d79e78f07145186f2", null ],
    [ "points_begin", "classCGAL_1_1Polyhedron__3.html#a25d5ad0a16bbcf71ca1f48225b43bc95", null ],
    [ "points_end", "classCGAL_1_1Polyhedron__3.html#a45bf32fbaf7f185558e18194e4ab3830", null ],
    [ "reserve", "classCGAL_1_1Polyhedron__3.html#a545fadc0f4af7a1e4a1a0d1e26711f17", null ],
    [ "size_of_border_edges", "classCGAL_1_1Polyhedron__3.html#a1a1dbed72ce1b001446dd3ce25155d30", null ],
    [ "size_of_border_halfedges", "classCGAL_1_1Polyhedron__3.html#af156bdee96bbf065953569fe026795d9", null ],
    [ "size_of_facets", "classCGAL_1_1Polyhedron__3.html#a07c305cf6da9eeecc89fea2fc4f24f67", null ],
    [ "size_of_halfedges", "classCGAL_1_1Polyhedron__3.html#a022b5c320996fabb49673d8921437fcb", null ],
    [ "size_of_vertices", "classCGAL_1_1Polyhedron__3.html#ad661d362a8e515d67108803796eabac8", null ],
    [ "split_edge", "classCGAL_1_1Polyhedron__3.html#ab3269baf4b4c6ce61b86545b8fa360d2", null ],
    [ "split_facet", "classCGAL_1_1Polyhedron__3.html#a3ef41ae6c3be7f0894479f3dd4fe34d5", null ],
    [ "split_loop", "classCGAL_1_1Polyhedron__3.html#a375a1b49bc6ad2ad5c578d7a7c45e4f5", null ],
    [ "split_vertex", "classCGAL_1_1Polyhedron__3.html#a2b17d7bd2045397167b00616f3b4d622", null ],
    [ "traits", "classCGAL_1_1Polyhedron__3.html#a2eff5c59b448f9be755cb76cdf06d966", null ],
    [ "vertex_handles", "classCGAL_1_1Polyhedron__3.html#a2e0843aaeeadc428e8cd25802109bdf5", null ],
    [ "vertices_begin", "classCGAL_1_1Polyhedron__3.html#a94eec0aaf19925a005e5296d6c965c55", null ],
    [ "vertices_end", "classCGAL_1_1Polyhedron__3.html#aa402ee6ce24e0259a45c8579784a0f9a", null ],
    [ "operator<<", "group__PkgPolyhedronIOFunc.html#gae76f7723a658ce16b88063ee8a17805f", null ],
    [ "operator>>", "group__PkgPolyhedronIOFunc.html#gaf1ce25670b5796744cd6af0acce1562b", null ]
];
